/*
Description: 
This widget generates a list of cards that can be useful when the user wants
a card that showcases a status of an event alongisde basic details.
The card displays a short status as text on top right and a heading and a subheading in the bottom part.


Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-StatusCard.dart';

Usage:
The widget accepts a list of card objects of the StatusCardData class.
It returns a collection of cards. This collection can be received by the user for any widget that
uses 'children' property like a GridView, PageView, Column etc.

//Defining card objects
 List<StatusCardData> statusCardsArray = [];
    StatusCardData statusCard = new StatusCardData(
        heading: 'Heading',
        subheading: 'Subheading',
        backgroundColor: Colors.orange,
        cardHeight: 300,
        cardWidth: 200,
        headingTextFamily: 'Roboto',
        headingTextSize: 20,
        headingTextColor: Colors.black,
        headingTextWeight: FontWeight.normal,
        subheadingTextFamily: 'Roboto',
        subheadingTextSize: 14,
        subheadingTextColor: Colors.black,
        subheadingTextWeight: FontWeight.bold,
        status: 'New',
        statusTextFamily: 'Roboto',
        statusTextSize: 10,
        statusTextColor: Colors.white,
        statusTextWeight: FontWeight.normal,
        statusBackground: Colors.black,
        cardRadius: 6,
        statusRadius: 30);
    statusCardsArray.add(statusCard);
    cardTappedCallback(int index) {
      print(index);
    }
    
// Calling the widget
  StatusCard(statusCardsArray, cardTappedCallback) - Note: returns multiple items.

Author:
Rishabh Thakur
*/
import 'dart:core';
import 'package:flutter/material.dart';
import 'widget-classesUsed.dart';

List<Widget> StatusCard(List<StatusCardData> params, Function(int) callback) {
  List<Widget> statusCards = [];

  for (var i = 0; i < params.length; i++) {
    Widget statusCard = InkWell(
      onTap: () {
        callback(i);
      },
      child: Container(
        height: params[i].cardHeight,
        width: params[i].cardWidth,
        decoration: BoxDecoration(
            color: params[i].backgroundColor,
            borderRadius: BorderRadius.circular(params[i].cardRadius)),
        padding: EdgeInsets.all(15),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: <Widget>[
                RaisedButton(
                    onPressed: () {},
                    child: Text(
                      params[i].status,
                      style: TextStyle(
                          fontSize: params[i].statusTextSize,
                          fontFamily: params[i].statusTextFamily,
                          fontWeight: params[i].statusTextWeight,
                          color: params[i].statusTextColor),
                    ),
                    color: params[i].statusBackground,
                    shape: RoundedRectangleBorder(
                        borderRadius:
                            BorderRadius.circular(params[i].statusRadius)))
              ],
            ),
            Spacer(
              flex: 8,
            ),
            Text(
              params[i].heading,
              style: TextStyle(
                  color: params[i].headingTextColor,
                  fontFamily: params[i].headingTextFamily,
                  fontSize: params[i].headingTextSize,
                  fontWeight: params[i].headingTextWeight),
            ),
            SizedBox(
              height: 20,
            ),
            Text(
              params[i].subheading,
              style: TextStyle(
                  color: params[i].subheadingTextColor,
                  fontFamily: params[i].subheadingTextFamily,
                  fontSize: params[i].subheadingTextSize,
                  fontWeight: params[i].subheadingTextWeight),
            ),
            Spacer(flex: 2)
          ],
        ),
      ),
    );
    statusCards.add(statusCard);
  }
  return statusCards;
}
