/*
Description:
Button is implemented with  accept text and icons that can accept multiple buttons as objects.
There are three types of buttons, namely, primary, secondary and tertiary and the user can implement a separate widget for each of them.

Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-button-bar.dart';

Usage:
The user has to pass a list of objects containing a text, an icon for the button bar.
The text is a string type and icon is the Icon type data. The user can edit other constants from the constants file provided as per requirement.

onPressed(bool s)
    {
      print(s);
    }
    onLongPressed(bool s)
    {
    print (s);
    }

    List<ButtonBarList> buttons = [];
    ButtonBarList button1 = new ButtonBarList(
        "okay", Icon(Icons.favorite));
    ButtonBarList
    button2 = new ButtonBarList(
        "cancel", Icon(Icons.arrow_back));

    buttons.add(button1);
    buttons.add(button2);

Object Call for the widget:
PrimaryButtons(ButtonBarParameters(list: buttons),onPressed, onLongPressed),
SecondaryButtons(ButtonBarParameters(list: buttons),onPressed, onLongPressed),
TertiaryButtons(ButtonBarParameters(list: buttons),onPressed, onLongPressed)

Author:
Ishita Agrawal

*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart';



Widget PrimaryButtons(ButtonBarParameters param, void Function(bool) onPressed,
    void Function(bool) onLongPressed) {
  if (param == null && onPressed == null && onLongPressed == null) {
    List<RaisedButton> button = [];
    var raisedbutton;

    raisedbutton = RaisedButton.icon(
      color: MediumGreyThemeData().buttonColor,
      textColor: MediumGreyThemeData().primaryColor,
      disabledTextColor: MediumGreyThemeData().disabledColor,
      label: Text(text_button),
      icon: Icon(Icons.access_time),
      highlightElevation: button_heightElevation,
      elevation: button_elevation,
      disabledElevation: button_disabledElevation,
      hoverColor: MediumGreyThemeData().hoverColor,
      onPressed: () {
        return onPressed(true);

      },
      onLongPress: () {
        return onLongPressed(true);
      },
      shape: new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(button_borderRadius),
          side: BorderSide(
              color: MediumGreyThemeData().buttonColor,
              width: button_borderWidth)),
      focusColor: MediumGreyThemeData().primaryColor,
    );
    button.add(raisedbutton);

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  } else {
    List<RaisedButton> button = [];
    var raisedbutton;

    for (var button1 = 0; button1 < param.list.length; button1++) {
      raisedbutton = new RaisedButton.icon(
        color: param.ButtonbgColor != null
            ? param.ButtonbgColor
            : MediumGreyThemeData().buttonColor,
        textColor: param.textColor != null
            ? param.textColor
            : MediumGreyThemeData().primaryColor,
        disabledTextColor: param.disabledTextColor != null
            ? param.disabledTextColor
            : MediumGreyThemeData().disabledColor,
        label: Text(param.list[button1].text != null
            ? param.list[button1].text
            : text_button),
        icon: param.list[button1].icons != null
            ? param.list[button1].icons
            : Icon(Icons.access_time),

        hoverColor: param.hoverColor != null
            ? param.hoverColor
            : MediumGreyThemeData().hoverColor,
        onPressed: () {
          onPressed != null ? onPressed : onPressed(true);
        },
        onLongPress: () {
          onPressed != null ? onLongPressed : onLongPressed(true);
        },
        shape: new RoundedRectangleBorder(
            borderRadius: new BorderRadius.circular(param.button_borderRadius != null
                ? param.button_borderRadius
                : button_borderRadius),
            side: BorderSide(
                color: param.borderColor != null
                    ? param.borderColor
                    : MediumGreyThemeData().buttonColor,
                width: param.borderWidth != null
                    ? param.borderWidth
                    : button_borderWidth)),
        focusColor: param.focusColor != null
            ? param.focusColor
            : MediumGreyThemeData().primaryColor,
      );
      button.add(raisedbutton);
    }

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  }
}

Widget SecondaryButtons(ButtonBarParameters param,
    void Function(bool) onPressed, void Function(bool) onLongPressed) {
  if (param == null && onPressed == null && onLongPressed == null) {
    List<FlatButton> button = [];
    var flatbutton;

    flatbutton = FlatButton.icon(
      textColor: MediumGreyThemeData().textSelectionColor,
      disabledTextColor: MediumGreyThemeData().disabledColor,
      label: Text(text_button),
      icon: Icon(Icons.access_time),
      hoverColor: MediumGreyThemeData().hoverColor,
      onPressed: () {
        return onPressed(true);
      },
      onLongPress: () {
        return onLongPressed(true);
      },
      shape: new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular(button_borderRadius),
          side: BorderSide(
              color: MediumGreyThemeData().buttonColor,
              width: button_borderWidth)),
      focusColor: MediumGreyThemeData().primaryColor,
    );
    button.add(flatbutton);

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  } else {
    List<FlatButton> button = [];
    var flatbutton;

    for (var button1 = 0; button1 < param.list.length; button1++) {
      flatbutton = new FlatButton.icon(
        textColor: param.textColor != null
            ? param.textColor
            : MediumGreyThemeData().primaryColor,
        disabledTextColor: param.disabledTextColor != null
            ? param.disabledTextColor
            : MediumGreyThemeData().disabledColor,
        label: Text(param.list[button1].text != null
            ? param.list[button1].text
            : text_button),
        icon: param.list[button1].icons != null
            ? param.list[button1].icons
            : Icon(Icons.access_time),
        hoverColor: param.hoverColor != null
            ? param.hoverColor
            : MediumGreyThemeData().hoverColor,
        onPressed: () {
          onPressed != null ? onPressed : onPressed(true);

        },
        onLongPress: () {
          onPressed != null ? onLongPressed : onLongPressed(true);
        },
        shape: new RoundedRectangleBorder(
            borderRadius: new BorderRadius.circular(param.button_borderRadius != null
                ? param.button_borderRadius
                : button_borderRadius),
            side: BorderSide(
                color: param.borderColor != null
                    ? param.borderColor
                    : MediumGreyThemeData().buttonColor,
                width: param.borderWidth != null
                    ? param.borderWidth
                    : button_borderWidth)),
        focusColor: param.focusColor != null
            ? param.focusColor
            : MediumGreyThemeData().primaryColor,
      );
      button.add(flatbutton);
    }

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  }
}

Widget TertiaryButtons(ButtonBarParameters param, void Function(bool) onPressed,
    void Function(bool) onLongPressed) {
  if (param == null && onPressed == null && onLongPressed == null) {
    List<FlatButton> button = [];
    var flatbutton;

    flatbutton = FlatButton.icon(
      textColor: MediumGreyThemeData().textSelectionColor,
      disabledTextColor: MediumGreyThemeData().disabledColor,
      label: Text(text_button),
      icon: Icon(Icons.access_time),
      hoverColor: MediumGreyThemeData().hoverColor,
      onPressed: () {
        return onPressed(true);
      },
      onLongPress: () {
        return onLongPressed(true);
      },
      shape: new RoundedRectangleBorder(
        borderRadius: new BorderRadius.circular(button_borderRadius),
      ),
      focusColor: MediumGreyThemeData().primaryColor,
    );
    button.add(flatbutton);

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  } else {
    List<FlatButton> button = [];
    var flatbutton;

    for (var button1 = 0; button1 < param.list.length; button1++) {
      flatbutton = new FlatButton.icon(
        textColor: param.textColor != null
            ? param.textColor
            : MediumGreyThemeData().primaryColor,
        disabledTextColor: param.disabledTextColor != null
            ? param.disabledTextColor
            : MediumGreyThemeData().disabledColor,
        label: Text(param.list[button1].text != null
            ? param.list[button1].text
            : text_button),
        icon: param.list[button1].icons != null
            ? param.list[button1].icons
            : Icon(Icons.access_time),
        hoverColor: param.hoverColor != null
            ? param.hoverColor
            : MediumGreyThemeData().hoverColor,
        onPressed: () {
          onPressed != null ? onPressed : onPressed(true);
        },
        onLongPress: () {
          onPressed != null ? onLongPressed : onLongPressed(true);
        },
        shape: new RoundedRectangleBorder(
          borderRadius: new BorderRadius.circular( button_borderRadius),
        ),
        focusColor: param.focusColor != null
            ? param.focusColor
            : MediumGreyThemeData().primaryColor,
      );
      button.add(flatbutton);
    }

    return ButtonBar(
      buttonPadding: EdgeInsets.all(button_edgeInsetsAll),
      buttonHeight: button_height,
      buttonMinWidth: button_width,
      children: button,
    );
  }
}
