/*
Description:

Dynamically creates an Icon Button material widget which responds to a press.


Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-iconButton.dart';

Usage:
The 'icon' parameter accepts IconData to be displayed on the button.
The parameters such as iconSize,color,focusColor,hoverColor,highlightColor,splashColor,etc can be passed using the class 'IconButtonParameters'.
onPress callback function can be passed which return a 'true' value and can be used to define further actions to be performed on press of the button.
An Icon Button with default parameters is created if null is passed as IconButtonParameters.


- Defining the callback and Icon Button objects

onButtonPress(bool b){
      print(b);
    }


IconButtonParameters iconButtonObject = IconButtonParameters(icon: Icons.shopping_cart,color: Colors.orange,iconSize: 30,hoverColor: Colors.orange,splashColor: Colors.orange);



- Object call for the widget

CustomIconButton(iconButtonObject, onButtonPress)

Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'consts.dart' as con;
import 'widget-classesUsed.dart';
import 'theme.dart';

Widget CustomIconButton(
    IconButtonParameters param, void Function(bool) onPress) {
  if (param == null && onPress == null) {
    return IconButton(
      alignment: Alignment.center,
      color: MediumGreyThemeData().buttonColor,
      disabledColor: MediumGreyThemeData().disabledColor,
      focusColor: MediumGreyThemeData().focusColor,
      highlightColor: MediumGreyThemeData().highlightColor,
      hoverColor: MediumGreyThemeData().hoverColor,
      icon: Icon(con.icon_add),
      iconSize: con.icon_size,
      onPressed: () {},
      splashColor: MediumGreyThemeData().splashColor,
    );
  } else {
    return IconButton(
      alignment: (param.alignment != null) ? param.alignment : Alignment.center,
      color: (param.color != null)
          ? param.color
          : MediumGreyThemeData().buttonColor,
      disabledColor: (param.disabledColor != null)
          ? param.disabledColor
          : MediumGreyThemeData().disabledColor,
      focusColor: (param.focusColor != null)
          ? param.focusColor
          : MediumGreyThemeData().focusColor,
      highlightColor: (param.highlightColor != null)
          ? param.highlightColor
          : MediumGreyThemeData().highlightColor,
      hoverColor: (param.hoverColor != null)
          ? param.hoverColor
          : MediumGreyThemeData().hoverColor,
      icon: (param.icon != null) ? (Icon(param.icon)) : Icon(con.icon_add),
      iconSize: (param.iconSize != null) ? param.iconSize : con.icon_size,
      onPressed: () {
        return (onPress != null) ? onPress(true) : null;
      },
      splashColor: (param.splashColor != null)
          ? param.splashColor
          : MediumGreyThemeData().splashColor,
      autofocus: (param.autofocus != null) ? param.autofocus : false,
      tooltip: param.tooltip,
    );
  }
}
