/*
Description:
This card has a title on the top, a subtitle below that and a button below that It has an image on the lower part of the card

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-reverse-card.dart';

Usage:
-Creating the object for the card

    callback(int nIndex, String sText1, String sText2, String img) async {
      print(nIndex);
      print(sText1);
      print(sText2);
    }
    MaterialCardData Obj1 = new MaterialCardData(
        title: "Life Pension Guarentee Plan",
        subtitle: "Life Pension Guaranteed Plan is a single premium annuity product which provides a regular guaranteed income for lifetime.",
        containerHeight: 500.0,
        containerWidth: 320.0,
        containerDecoration: BoxDecoration(
          boxShadow: [
            BoxShadow(
                color: Colors.white,
                blurRadius: 10,
                offset: Offset.zero)
          ],
          borderRadius: BorderRadius.circular(20),
          color: Colors.white,
        ),
        textStyle1: TextStyle(
          color: Colors.black,
          fontSize: 20,
          fontWeight: FontWeight.bold,
        ),
        textStyle2: TextStyle(
          color: Colors.black,
          fontSize: 16.0,
        ),
        btnText: "View",
        btnTextColor: Colors.black,
        btnColor: Colors.black,
        imgType: "Network",
        imgPath: "https://www.mylabathome.com/wp-content/uploads/2018/05/Indian-family.jpg");


    -Object call for the widget
        body: customReverseMaterialCard(Obj1, callback),

    Author:
    Karan Arora
*/

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

Widget customReverseMaterialCard(
    MaterialCardData data, void Function(int, String, String,String) callback) {
  ImageProvider image;
  if(data.imgType == "Asset"){
    image=(data.imgPath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : AssetImage(data.imgPath);
  }

  else if(data.imgType == "Network"){
    image=(data.imgPath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : NetworkImage(data.imgPath);

  }

  else{
      image = NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png");
  }


  return Material(
    type: MaterialType.transparency,
    child: Container(
      decoration: (data.containerDecoration != null) ? data.containerDecoration : BoxDecoration(
        boxShadow: [
          BoxShadow(
              color: MediumGreyThemeData().backgroundColor,
              blurRadius: constants.heightTen,
              offset: Offset.zero)
        ],
        borderRadius: BorderRadius.circular(constants.heightTwenty),
        color: MediumGreyThemeData().accentColor,
      ),
      height: (data.containerHeight != null) ? data.containerHeight : constants.heightFourHundred,
      width: (data.containerWidth != null) ? data.containerWidth : constants.heightThreeHundred,
      child: SingleChildScrollView(
          child: Container(
              decoration: (data.Decoration1 != null) ? data.Decoration1 : BoxDecoration(
                borderRadius: BorderRadius.circular(constants.heightTwenty),
              ),
              height: constants.heightFiveHundred,
              child: Column(
                  children:<Widget>[
                    Container(
                      decoration: (data.Decoration2 != null) ? data.Decoration2 : BoxDecoration(
                        borderRadius: BorderRadius.circular(constants.heightTwenty),
                      ),
                      child: Column(
                          children: <Widget>[
                            ListTile(
                              title: Text(
                                (data.title != null) ? data.title : constants.cardTitle,
                                style: (data.textStyle1 != null) ? data.textStyle1 : TextStyle(
                                  color: MediumGreyThemeData().textSelectionColor,
                                  fontSize: constants.fontMedium,
                                  fontWeight: constants.fontBold,
                                ),
                                overflow: TextOverflow.ellipsis,
                              ),
                              contentPadding: EdgeInsets.all((data.padding1 != null) ? data.padding1 : constants.heightTwenty),
                              subtitle: Padding(
                                padding: const EdgeInsets.only(top:constants.heightTwenty),
                                child: Text(
                                  (data.subtitle != null)
                                      ? data.subtitle
                                      : constants.cardSubtitle,
                                  style: (data.textStyle2 != null) ? data.textStyle2 : TextStyle(
                                    color: MediumGreyThemeData().textSelectionColor,
                                    fontSize: constants.fontMedium,
                                  ),
                                  overflow: TextOverflow.ellipsis,
                                  maxLines: constants.maxLines,
                                  softWrap: true,
                                ),
                              ),
                            ),
                            Align(
                              alignment: Alignment.centerRight,
                              child: Padding(
                                padding: const EdgeInsets.only(left:constants.heightTwentyFive,right: constants.heightTwentyFive,top: constants.heightTen,bottom: constants.heightTen),
                                child: OutlineButton(
                                  textColor: (data.btnTextColor != null) ? data.btnTextColor : MediumGreyThemeData().textSelectionColor,
                                  borderSide: BorderSide(color: (data.btnColor != null) ? data.btnColor : MediumGreyThemeData().buttonColor),
                                  shape:(data.shapeButton != null) ? data.shapeButton : RoundedRectangleBorder(
                                      borderRadius: new BorderRadius.circular(constants.heightTwenty)),
                                  onPressed: (){
                                    callback(0,data.title,data.subtitle,data.imgPath);
                                  },
                                  child: Text((data.btnText != null) ? data.btnText : constants.cardBtnText),
                                ),
                              ),
                            ),
                          ]),
                    ),
                    Card(
                      child: Container(
                        height: (data.imgHeight != null) ? data.imgHeight : constants.heightOneEighty,
                        decoration: BoxDecoration(
                          image: DecorationImage(
                              image: (image != null) ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
                              fit: BoxFit.fill),
                        ),
                      ),
                    ),
                  ]
              )
          )
      ),
    ),
  );
}
