/*
Description:
A widget that combines the search functionality with the App bar.
On clicking the search button in the App Bar, A text field appears below the App Bar.
The result of the search field (text box) are returned back to the user who can then map it accordingly.
The sample implementations showcases stubbed ListTiles as search results.

Imports:
import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_widgets_library/view/composite-widgets/custom-searchWidget.dart';

Usage:
The user will initialize and define variables for the following:
1. Creating an App Bar by defining its properties like shape, icon, text etc.
2. List of icons to be displayed in the App Bar
3. Properties for the search text field like maximum length, obscure text etc.
4. Callback function for List Tiles and text field. This is generic callback as of now which
can be modified in order to produce dynamic results using an API call etc.
5. Properties for search text field
6. Widget Parameters for text Field

// Defining all required objects for the search bar widget
      CustomListTileParameters listTileParameters = new CustomListTileParameters(
        fontFamily: "Roboto",
        listBgColor: Colors.white,
        textColor: Colors.black,
        contentPadding: EdgeInsets.only(top: 20, bottom: 20));

    AppBarParameters appBarParams = new AppBarParameters(
        backgroundColor: Colors.red,
        elevation: 5,
        bottomOpacity: 2.0,
        toolbarOpacity: 1.0,
        titleSpacing: 1.0,
        centerTitle: false,
        title: Image.asset('images/vic-logo.png',
            height: 50, width: 50, semanticLabel: "V.I.C App Logo"));

    List<Widget> appBarIcons = [
      IconButton(
        icon: Icon(Icons.arrow_back),
        onPressed: () {
          Navigator.pop(context);
        },
      ),
      IconButton(
        icon: SvgPicture.asset(
          'images/graphs.svg',
          height: 20,
          width: 20,
        ),
        tooltip: 'Opens Graphs',
        onPressed: () {},
      )
    ];

    onClickCallback(int nIndex, String title) {
      print(nIndex);
      print(title);
    }

    TextFieldParameters textFieldParams = new TextFieldParameters(
        maxLength: 20,
        obsecureText: false,
        maxLengthEnforced: false,
        cursorColor: Colors.black,
        cursorRadius: Radius.circular(50),
        style: TextStyle(fontFamily: "Roboto", color: Colors.black),
        decoration: InputDecoration(
          counterText: "",
          prefixIcon: Icon(
            Icons.search,
            color: Colors.black,
          ),
          filled: true,
          fillColor: Colors.white,
          hintText: "Search for partners",
          hintStyle: TextStyle(color: Colors.black),
          focusColor: Colors.black,
        ));
        
// Calling the search bar composite widget
    CustomSearchBar(appBarParams, listTileParameters, appBarIcons, onClickCallback, textFieldParams)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';
import 'custom-appbar.dart';
import 'custom-listTileWithImage.dart';
import 'custom-textField.dart';

class CustomSearchBar extends StatefulWidget {
  AppBarParameters appBarParams;
  CustomListTileParameters listTileParams;
  List<Widget> appBarIcons;
  Function(int, String) callback;
  TextFieldParameters textFieldParams;
  CustomSearchBar(this.appBarParams, this.listTileParams, this.appBarIcons,
      this.callback, this.textFieldParams);
  @override
  State<StatefulWidget> createState() {
    return _customSearchBar(this.appBarParams, this.listTileParams,
        this.appBarIcons, this.callback, this.textFieldParams);
  }
}

class _customSearchBar extends State<CustomSearchBar> {
  AppBarParameters appBarParams;
  CustomListTileParameters listTileParams;
  List<Widget> appBarIcons;
  Function(int, String) callback;
  TextFieldParameters textFieldParams;
  _customSearchBar(this.appBarParams, this.listTileParams, this.appBarIcons,
      this.callback, this.textFieldParams);
  List<CustomTileData> tileData = [];
  @override
  Widget build(BuildContext context) {
    onTextSubmit(String sText) {
      setState(() {
        tileData = [];
        CustomTileData searchItem1 = new CustomTileData(
            leading: Icon(cons.icon1),
            title: sText,
            subtitle: cons.cardSubtitle,
            trailingTopText: cons.listTop,
            trailingBottomText: cons.listBottom);
        tileData.add(searchItem1);
      });
    }

    return Scaffold(
      appBar: CustomAppBar(appBarIcons, appBarParams),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            CustomTextField(
                params: textFieldParams, callbackTextfield: onTextSubmit),
            CustomListTile(tileData, listTileParams, callback)
          ],
        ),
      ),
    );
  }
}
