/*
Description:

Dynamically creates a tooltip functionality around a widget (Usually a Button).
On long pressing the button, we get some information around its usage as a hovering text.

Imports: 
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-toolTip.dart';

Usage:
- Defining the callback for child(button) and Tooltip objects

tooltipCallback(bool active) {
      print('Button was pressed');
    }

CustomToolTipParams toolTipParams = new CustomToolTipParams(
        message: "Tooltip Message",
        padding: EdgeInsets.all(10),
        margin: EdgeInsets.all(5),
        child: RaisedButton(
          onPressed: () {},
          child: Text("Button"),
        ),
        decoration: BoxDecoration(
            color: Colors.red, borderRadius: BorderRadius.circular(10)));

- Calling the widget from inside the Scaffold

CustomToolTip(toolTipParams, tooltipCallback)

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';

Widget CustomToolTip(
    CustomToolTipParams tooltipParameters, Function(bool) callback) {
  // If no parameters are passed to the Widget
  if (tooltipParameters == null) {
    return Tooltip(
      message: cons.sampleText,
      child: RaisedButton(
        child: Icon(cons.icon1, color: MediumGreyThemeData().iconTheme.color),
        onPressed: () {
          return callback(true);
        },
        color: MediumGreyThemeData().floatingActionButtonTheme.backgroundColor,
      ),
      height: cons.heightTwentyPixel,
      decoration: BoxDecoration(color: MediumGreyThemeData().primaryColorDark),
    );
  } else {
    // If all or limited parameters are passed to the Widget
    return Tooltip(
      padding: (tooltipParameters.padding != null)
          ? tooltipParameters.padding
          : EdgeInsets.all(cons.onePixelDouble),
      margin: (tooltipParameters.margin != null)
          ? tooltipParameters.margin
          : EdgeInsets.all(cons.onePixelDouble),
      message:
          (tooltipParameters.message == null || tooltipParameters.message == "")
              ? cons.sampleText
              : tooltipParameters.message,
      child: (tooltipParameters.child != null)
          ? tooltipParameters.child
          : RaisedButton(
              child: Icon(cons.icon2,
                  color: MediumGreyThemeData().iconTheme.color),
              onPressed: () {
                if (callback != null) {
                  return callback(true);
                }
              },
              color: MediumGreyThemeData()
                  .floatingActionButtonTheme
                  .backgroundColor,
            ),
      height: (tooltipParameters.height != null)
          ? tooltipParameters.height
          : cons.heightTwentyPixel,
      decoration: (tooltipParameters.decoration != null)
          ? tooltipParameters.decoration
          : BoxDecoration(color: MediumGreyThemeData().primaryColorDark),
    );
  }
}
