/*
Description:
A widget that creates a custom Slider that user can drag to input a numerical value within the specified range.
It also has divisions which divides the line into equal parts for easier sliding.

Usage:
The user can pass in  maximum value, minimum value and number of divisions of the slider .
The user can also pass on other parameters like active track colour and inactive track colour etc.
See CustomSliderContents and CustomSliderParameters class definitons for more information.
The user also passes a callback function which is invoked when the Slider is used.
- The widget returns the current value of the slider.

  onSlide(double sdouble) {
    print(sdouble);
  }

SliderParameters finalObject = new SliderParameters(inactiveColor: Colors.red, label: "Custom Slider", divisions: 3, max: 30, min: 0, activeColor: Colors.pink);

    CustomSlider(param: finalObject, callbackSlider: onSlide)

    imports: 
    import 'dart:core';
    import 'package:flutter/material.dart';
    import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
    import 'custom_slider.dart';

Author:
Anubhav Sinha
*/

import 'dart:core';
import 'package:flutter/material.dart';
import 'theme.dart';
import 'consts.dart' as cons;
import 'widget-classesUsed.dart';


class CustomSlider extends StatefulWidget {

  final SliderParameters param;
  final void Function(double) callbackSlider;
  const CustomSlider({
    Key key,

    this.param,
    this.callbackSlider

  }) :
        super(key: key);
  @override
  _CustomSliderState createState() => _CustomSliderState(
      this.param,
      this.callbackSlider
  );
}
class _CustomSliderState extends State<CustomSlider> {
  SliderParameters param;
  void Function(double) callbackSlider;
  _CustomSliderState(
      SliderParameters param,
      Function(double) callbackSlider
      ){
    this.param = param;
    this.callbackSlider = callbackSlider;

  }
  double _value = 0.0;
  //print();
  @override
  Widget build(BuildContext context) {
// TODO: implement build
    if (param == null) {
      return Slider(
        divisions: cons.DIVS,
        min: cons.MIN,
        max: cons.MAX,
        activeColor: Theme.of(context).focusColor,
        inactiveColor: Theme.of(context).disabledColor,
        value: _value,
        onChanged: (value) {
          setState(() {
            _value = value;
          });
          callbackSlider(_value);
        },
      );
    } //if
    else{
      return Slider(
        divisions: (param.divisions != null)? param.divisions: cons.DIVS,
        max: (param.max != null)? param.max: cons.MAX,
        min: (param.min != null)? param.min: cons.MIN,
        activeColor: (param.activeColor != null)? param.activeColor: Theme.of(context).focusColor,
        inactiveColor: Theme.of(context).disabledColor,
        value: _value,
        onChanged: (value) {
          setState(() {
            _value = value;
          });
          callbackSlider(_value);
        },
      );

    }
  }
}