import 'package:flutter/material.dart';
import 'consts.dart' ;
import 'widget-classesUsed.dart';
import 'custom-flipcard.dart';
import 'Custom-SplitCard.dart';
import 'custom-TransparentCard.dart';

/*
Imports Required:
import 'customcard-grid.dart';
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';


This widget is used to display a Grid View.
    This grid view can encompass multiple kinds of cards.
    The type of card has to be specified by the user.(Options :transparentcard, fiftycard, flipcard, default)
    The individual cards can be tapped to perform certain functions.
    The user can also specify the cross axis count and the callback functions.

    SAMPLE IMPLEMENTATION:

    final MaterialCardData MaterialCardata2 = new MaterialCardData(
        title: 'Taj Mahal',
        subtitle: 'This mausoleum complex in Agra, India, is regarded as one of the world’s most iconic monuments and is perhaps the finest example of Mughal architecture',
        imgPath: "https://cdn.britannica.com/86/170586-050-AB7FEFAE/Taj-Mahal-Agra-India.jpg"
    );
    final MaterialCardData MaterialCardata3 = new MaterialCardData(
        title: 'Colosseum',
        subtitle: 'The Colosseum in Rome was built in the first century by order of the Emperor Vespasian',
        imgPath: "https://cdn.britannica.com/75/75775-050-1FC4B34B/Colosseum-Rome.jpg"
    );
    final MaterialCardData MaterialCardata4 = new MaterialCardData(
        title: 'Petra',
        subtitle: 'The ancient city of Petra, Jordan, is located in a remote valley, nestled among sandstone mountains and cliffs',
        imgPath: "https://cdn.britannica.com/88/189788-050-9B5DB3A4/Al-Dayr-Petra-Jordan.jpg"
    );
    onclickGrid(int nIndex, String sText) {
      print(nIndex);
      print(sText);
    }
    onLongPressGrid(int nIndex, String Text1, String Text2) {
      print(nIndex);
      print(Text1);
      print(Text2);
    }
    List<MaterialCardData> AreaList = [];

    AreaList.add(MaterialCardata2);

    AreaList.add(MaterialCardata3);
    AreaList.add(MaterialCardata4);
    CustomGrid gridobj = new CustomGrid(1,onclickGrid, onLongPressGrid,16.0, 16.0,"fiftycard",);
    CustomisedGridView(AreaList, gridobj);
    CustomGrid gridobj2 = new CustomGrid(1,onclickGrid, onLongPressGrid,16.0, 16.0,"flipcard",);


        body: CustomisedGridView(AreaList, gridobj2)

*/

//AUTHOR : Soumyadeep Mitra

//WIDGET IMPLEMENTATION
Widget CustomisedGridView(List<MaterialCardData> data, CustomGrid gridobj) {

  Widget card;

  return Container(
    child: new GridView.builder(

      itemCount: data.length,
      gridDelegate: new SliverGridDelegateWithFixedCrossAxisCount(
          crossAxisCount: gridobj.count,
          crossAxisSpacing: gridobj.cas,
          mainAxisSpacing: gridobj.mas),
      itemBuilder: (BuildContext context, int index) {
        if(gridobj.cardtype=='transparentcard')
        {
          card=ImageCardWidget(data[index], gridobj.callback);
        }
        else if(gridobj.cardtype=='fiftycard')
        {
          card=FiftyCardWidget(data[index], gridobj.callback);
        }
        else if(gridobj.cardtype=='flipcard')
        {
          card=customFlipCardWidget(data[index], gridobj.callback);
        }
        else if(gridobj.cardtype=='default')
        {
          card = new Card(
            color: Theme.of(context).cardColor,
            child: Column(
              children: <Widget>[
                SizedBox(height: heightTen),
                new Center(
                    child: Text(
                      data[index].title,
                      style: TextStyle(
                          color: Theme.of(context).primaryColorDark,
                          fontSize: font_small,
                          fontWeight: FontWeight.bold),
                    )),
                Expanded(child: Container(child: data[index].icon)),
                new Center(
                  child: Text(data[index].subtitle),
                ),
                SizedBox(height: heightTen),
              ],
            ),
          );
        }
        return InkWell(
            onTap: (){gridobj.callback(index,data[index].title);} ,
            onLongPress: (){gridobj.longcallback(index,data[index].title,data[index].subtitle);} ,
            child: card
        );
      },
    ),
  );
}